"""
dbsake.core.mysql.frm.charsets
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
MySQL character / collation lookup

This module contains minimal information about character sets
used when parsing .frm files.  Namely the maxlen of each byte
sequence is useful for decoding certain values.
"""

import collections

Charset = collections.namedtuple('Charset',
                                 'id name collation maxlen is_default')

CHARSETS = {
    32: Charset(id=32,
                name='armscii8',
                collation='armscii8_general_ci',
                is_default=True,
                maxlen=1),
    64: Charset(id=64,
                name='armscii8',
                collation='armscii8_bin',
                is_default=False,
                maxlen=1),
    11: Charset(id=11,
                name='ascii',
                collation='ascii_general_ci',
                is_default=True,
                maxlen=1),
    65: Charset(id=65,
                name='ascii',
                collation='ascii_bin',
                is_default=False,
                maxlen=1),
    1: Charset(id=1,
               name='big5',
               collation='big5_chinese_ci',
               is_default=True,
               maxlen=2),
    84: Charset(id=84,
                name='big5',
                collation='big5_bin',
                is_default=False,
                maxlen=2),
    63: Charset(id=63,
                name='binary',
                collation='binary',
                is_default=True,
                maxlen=1),
    26: Charset(id=26,
                name='cp1250',
                collation='cp1250_general_ci',
                is_default=True,
                maxlen=1),
    34: Charset(id=34,
                name='cp1250',
                collation='cp1250_czech_cs',
                is_default=False,
                maxlen=1),
    44: Charset(id=44,
                name='cp1250',
                collation='cp1250_croatian_ci',
                is_default=False,
                maxlen=1),
    66: Charset(id=66,
                name='cp1250',
                collation='cp1250_bin',
                is_default=False,
                maxlen=1),
    99: Charset(id=99,
                name='cp1250',
                collation='cp1250_polish_ci',
                is_default=False,
                maxlen=1),
    14: Charset(id=14,
                name='cp1251',
                collation='cp1251_bulgarian_ci',
                is_default=False,
                maxlen=1),
    23: Charset(id=23,
                name='cp1251',
                collation='cp1251_ukrainian_ci',
                is_default=False,
                maxlen=1),
    50: Charset(id=50,
                name='cp1251',
                collation='cp1251_bin',
                is_default=False,
                maxlen=1),
    51: Charset(id=51,
                name='cp1251',
                collation='cp1251_general_ci',
                is_default=True,
                maxlen=1),
    52: Charset(id=52,
                name='cp1251',
                collation='cp1251_general_cs',
                is_default=False,
                maxlen=1),
    57: Charset(id=57,
                name='cp1256',
                collation='cp1256_general_ci',
                is_default=True,
                maxlen=1),
    67: Charset(id=67,
                name='cp1256',
                collation='cp1256_bin',
                is_default=False,
                maxlen=1),
    29: Charset(id=29,
                name='cp1257',
                collation='cp1257_lithuanian_ci',
                is_default=False,
                maxlen=1),
    58: Charset(id=58,
                name='cp1257',
                collation='cp1257_bin',
                is_default=False,
                maxlen=1),
    59: Charset(id=59,
                name='cp1257',
                collation='cp1257_general_ci',
                is_default=True,
                maxlen=1),
    4: Charset(id=4,
               name='cp850',
               collation='cp850_general_ci',
               is_default=True,
               maxlen=1),
    80: Charset(id=80,
                name='cp850',
                collation='cp850_bin',
                is_default=False,
                maxlen=1),
    40: Charset(id=40,
                name='cp852',
                collation='cp852_general_ci',
                is_default=True,
                maxlen=1),
    81: Charset(id=81,
                name='cp852',
                collation='cp852_bin',
                is_default=False,
                maxlen=1),
    36: Charset(id=36,
                name='cp866',
                collation='cp866_general_ci',
                is_default=True,
                maxlen=1),
    68: Charset(id=68,
                name='cp866',
                collation='cp866_bin',
                is_default=False,
                maxlen=1),
    95: Charset(id=95,
                name='cp932',
                collation='cp932_japanese_ci',
                is_default=True,
                maxlen=2),
    96: Charset(id=96,
                name='cp932',
                collation='cp932_bin',
                is_default=False,
                maxlen=2),
    3: Charset(id=3,
               name='dec8',
               collation='dec8_swedish_ci',
               is_default=True,
               maxlen=1),
    69: Charset(id=69,
                name='dec8',
                collation='dec8_bin',
                is_default=False,
                maxlen=1),
    97: Charset(id=97,
                name='eucjpms',
                collation='eucjpms_japanese_ci',
                is_default=True,
                maxlen=3),
    98: Charset(id=98,
                name='eucjpms',
                collation='eucjpms_bin',
                is_default=False,
                maxlen=3),
    19: Charset(id=19,
                name='euckr',
                collation='euckr_korean_ci',
                is_default=True,
                maxlen=2),
    85: Charset(id=85,
                name='euckr',
                collation='euckr_bin',
                is_default=False,
                maxlen=2),
    24: Charset(id=24,
                name='gb2312',
                collation='gb2312_chinese_ci',
                is_default=True,
                maxlen=2),
    86: Charset(id=86,
                name='gb2312',
                collation='gb2312_bin',
                is_default=False,
                maxlen=2),
    28: Charset(id=28,
                name='gbk',
                collation='gbk_chinese_ci',
                is_default=True,
                maxlen=2),
    87: Charset(id=87,
                name='gbk',
                collation='gbk_bin',
                is_default=False,
                maxlen=2),
    92: Charset(id=92,
                name='geostd8',
                collation='geostd8_general_ci',
                is_default=True,
                maxlen=1),
    93: Charset(id=93,
                name='geostd8',
                collation='geostd8_bin',
                is_default=False,
                maxlen=1),
    25: Charset(id=25,
                name='greek',
                collation='greek_general_ci',
                is_default=True,
                maxlen=1),
    70: Charset(id=70,
                name='greek',
                collation='greek_bin',
                is_default=False,
                maxlen=1),
    16: Charset(id=16,
                name='hebrew',
                collation='hebrew_general_ci',
                is_default=True,
                maxlen=1),
    71: Charset(id=71,
                name='hebrew',
                collation='hebrew_bin',
                is_default=False,
                maxlen=1),
    6: Charset(id=6,
               name='hp8',
               collation='hp8_english_ci',
               is_default=True,
               maxlen=1),
    72: Charset(id=72,
                name='hp8',
                collation='hp8_bin',
                is_default=False,
                maxlen=1),
    37: Charset(id=37,
                name='keybcs2',
                collation='keybcs2_general_ci',
                is_default=True,
                maxlen=1),
    73: Charset(id=73,
                name='keybcs2',
                collation='keybcs2_bin',
                is_default=False,
                maxlen=1),
    7: Charset(id=7,
               name='koi8r',
               collation='koi8r_general_ci',
               is_default=True,
               maxlen=1),
    74: Charset(id=74,
                name='koi8r',
                collation='koi8r_bin',
                is_default=False,
                maxlen=1),
    22: Charset(id=22,
                name='koi8u',
                collation='koi8u_general_ci',
                is_default=True,
                maxlen=1),
    75: Charset(id=75,
                name='koi8u',
                collation='koi8u_bin',
                is_default=False,
                maxlen=1),
    5: Charset(id=5,
               name='latin1',
               collation='latin1_german1_ci',
               is_default=False,
               maxlen=1),
    8: Charset(id=8,
               name='latin1',
               collation='latin1_swedish_ci',
               is_default=True,
               maxlen=1),
    15: Charset(id=15,
                name='latin1',
                collation='latin1_danish_ci',
                is_default=False,
                maxlen=1),
    31: Charset(id=31,
                name='latin1',
                collation='latin1_german2_ci',
                is_default=False,
                maxlen=1),
    47: Charset(id=47,
                name='latin1',
                collation='latin1_bin',
                is_default=False,
                maxlen=1),
    48: Charset(id=48,
                name='latin1',
                collation='latin1_general_ci',
                is_default=False,
                maxlen=1),
    49: Charset(id=49,
                name='latin1',
                collation='latin1_general_cs',
                is_default=False,
                maxlen=1),
    94: Charset(id=94,
                name='latin1',
                collation='latin1_spanish_ci',
                is_default=False,
                maxlen=1),
    2: Charset(id=2,
               name='latin2',
               collation='latin2_czech_cs',
               is_default=False,
               maxlen=1),
    9: Charset(id=9,
               name='latin2',
               collation='latin2_general_ci',
               is_default=True,
               maxlen=1),
    21: Charset(id=21,
                name='latin2',
                collation='latin2_hungarian_ci',
                is_default=False,
                maxlen=1),
    27: Charset(id=27,
                name='latin2',
                collation='latin2_croatian_ci',
                is_default=False,
                maxlen=1),
    77: Charset(id=77,
                name='latin2',
                collation='latin2_bin',
                is_default=False,
                maxlen=1),
    30: Charset(id=30,
                name='latin5',
                collation='latin5_turkish_ci',
                is_default=True,
                maxlen=1),
    78: Charset(id=78,
                name='latin5',
                collation='latin5_bin',
                is_default=False,
                maxlen=1),
    20: Charset(id=20,
                name='latin7',
                collation='latin7_estonian_cs',
                is_default=False,
                maxlen=1),
    41: Charset(id=41,
                name='latin7',
                collation='latin7_general_ci',
                is_default=True,
                maxlen=1),
    42: Charset(id=42,
                name='latin7',
                collation='latin7_general_cs',
                is_default=False,
                maxlen=1),
    79: Charset(id=79,
                name='latin7',
                collation='latin7_bin',
                is_default=False,
                maxlen=1),
    38: Charset(id=38,
                name='macce',
                collation='macce_general_ci',
                is_default=True,
                maxlen=1),
    43: Charset(id=43,
                name='macce',
                collation='macce_bin',
                is_default=False,
                maxlen=1),
    39: Charset(id=39,
                name='macroman',
                collation='macroman_general_ci',
                is_default=True,
                maxlen=1),
    53: Charset(id=53,
                name='macroman',
                collation='macroman_bin',
                is_default=False,
                maxlen=1),
    13: Charset(id=13,
                name='sjis',
                collation='sjis_japanese_ci',
                is_default=True,
                maxlen=2),
    88: Charset(id=88,
                name='sjis',
                collation='sjis_bin',
                is_default=False,
                maxlen=2),
    10: Charset(id=10,
                name='swe7',
                collation='swe7_swedish_ci',
                is_default=True,
                maxlen=1),
    82: Charset(id=82,
                name='swe7',
                collation='swe7_bin',
                is_default=False,
                maxlen=1),
    18: Charset(id=18,
                name='tis620',
                collation='tis620_thai_ci',
                is_default=True,
                maxlen=1),
    89: Charset(id=89,
                name='tis620',
                collation='tis620_bin',
                is_default=False,
                maxlen=1),
    35: Charset(id=35,
                name='ucs2',
                collation='ucs2_general_ci',
                is_default=True,
                maxlen=2),
    90: Charset(id=90,
                name='ucs2',
                collation='ucs2_bin',
                is_default=False,
                maxlen=2),
    128: Charset(id=128,
                 name='ucs2',
                 collation='ucs2_unicode_ci',
                 is_default=False,
                 maxlen=2),
    129: Charset(id=129,
                 name='ucs2',
                 collation='ucs2_icelandic_ci',
                 is_default=False,
                 maxlen=2),
    130: Charset(id=130,
                 name='ucs2',
                 collation='ucs2_latvian_ci',
                 is_default=False,
                 maxlen=2),
    131: Charset(id=131,
                 name='ucs2',
                 collation='ucs2_romanian_ci',
                 is_default=False,
                 maxlen=2),
    132: Charset(id=132,
                 name='ucs2',
                 collation='ucs2_slovenian_ci',
                 is_default=False,
                 maxlen=2),
    133: Charset(id=133,
                 name='ucs2',
                 collation='ucs2_polish_ci',
                 is_default=False,
                 maxlen=2),
    134: Charset(id=134,
                 name='ucs2',
                 collation='ucs2_estonian_ci',
                 is_default=False,
                 maxlen=2),
    135: Charset(id=135,
                 name='ucs2',
                 collation='ucs2_spanish_ci',
                 is_default=False,
                 maxlen=2),
    136: Charset(id=136,
                 name='ucs2',
                 collation='ucs2_swedish_ci',
                 is_default=False,
                 maxlen=2),
    137: Charset(id=137,
                 name='ucs2',
                 collation='ucs2_turkish_ci',
                 is_default=False,
                 maxlen=2),
    138: Charset(id=138,
                 name='ucs2',
                 collation='ucs2_czech_ci',
                 is_default=False,
                 maxlen=2),
    139: Charset(id=139,
                 name='ucs2',
                 collation='ucs2_danish_ci',
                 is_default=False,
                 maxlen=2),
    140: Charset(id=140,
                 name='ucs2',
                 collation='ucs2_lithuanian_ci',
                 is_default=False,
                 maxlen=2),
    141: Charset(id=141,
                 name='ucs2',
                 collation='ucs2_slovak_ci',
                 is_default=False,
                 maxlen=2),
    142: Charset(id=142,
                 name='ucs2',
                 collation='ucs2_spanish2_ci',
                 is_default=False,
                 maxlen=2),
    143: Charset(id=143,
                 name='ucs2',
                 collation='ucs2_roman_ci',
                 is_default=False,
                 maxlen=2),
    144: Charset(id=144,
                 name='ucs2',
                 collation='ucs2_persian_ci',
                 is_default=False,
                 maxlen=2),
    145: Charset(id=145,
                 name='ucs2',
                 collation='ucs2_esperanto_ci',
                 is_default=False,
                 maxlen=2),
    146: Charset(id=146,
                 name='ucs2',
                 collation='ucs2_hungarian_ci',
                 is_default=False,
                 maxlen=2),
    147: Charset(id=147,
                 name='ucs2',
                 collation='ucs2_sinhala_ci',
                 is_default=False,
                 maxlen=2),
    148: Charset(id=148,
                 name='ucs2',
                 collation='ucs2_german2_ci',
                 is_default=False,
                 maxlen=2),
    149: Charset(id=149,
                 name='ucs2',
                 collation='ucs2_croatian_ci',
                 is_default=False,
                 maxlen=2),
    150: Charset(id=150,
                 name='ucs2',
                 collation='ucs2_unicode_520_ci',
                 is_default=False,
                 maxlen=2),
    151: Charset(id=151,
                 name='ucs2',
                 collation='ucs2_vietnamese_ci',
                 is_default=False,
                 maxlen=2),
    159: Charset(id=159,
                 name='ucs2',
                 collation='ucs2_general_mysql500_ci',
                 is_default=False,
                 maxlen=2),
    12: Charset(id=12,
                name='ujis',
                collation='ujis_japanese_ci',
                is_default=True,
                maxlen=3),
    91: Charset(id=91,
                name='ujis',
                collation='ujis_bin',
                is_default=False,
                maxlen=3),
    54: Charset(id=54,
                name='utf16',
                collation='utf16_general_ci',
                is_default=True,
                maxlen=4),
    55: Charset(id=55,
                name='utf16',
                collation='utf16_bin',
                is_default=False,
                maxlen=4),
    101: Charset(id=101,
                 name='utf16',
                 collation='utf16_unicode_ci',
                 is_default=False,
                 maxlen=4),
    102: Charset(id=102,
                 name='utf16',
                 collation='utf16_icelandic_ci',
                 is_default=False,
                 maxlen=4),
    103: Charset(id=103,
                 name='utf16',
                 collation='utf16_latvian_ci',
                 is_default=False,
                 maxlen=4),
    104: Charset(id=104,
                 name='utf16',
                 collation='utf16_romanian_ci',
                 is_default=False,
                 maxlen=4),
    105: Charset(id=105,
                 name='utf16',
                 collation='utf16_slovenian_ci',
                 is_default=False,
                 maxlen=4),
    106: Charset(id=106,
                 name='utf16',
                 collation='utf16_polish_ci',
                 is_default=False,
                 maxlen=4),
    107: Charset(id=107,
                 name='utf16',
                 collation='utf16_estonian_ci',
                 is_default=False,
                 maxlen=4),
    108: Charset(id=108,
                 name='utf16',
                 collation='utf16_spanish_ci',
                 is_default=False,
                 maxlen=4),
    109: Charset(id=109,
                 name='utf16',
                 collation='utf16_swedish_ci',
                 is_default=False,
                 maxlen=4),
    110: Charset(id=110,
                 name='utf16',
                 collation='utf16_turkish_ci',
                 is_default=False,
                 maxlen=4),
    111: Charset(id=111,
                 name='utf16',
                 collation='utf16_czech_ci',
                 is_default=False,
                 maxlen=4),
    112: Charset(id=112,
                 name='utf16',
                 collation='utf16_danish_ci',
                 is_default=False,
                 maxlen=4),
    113: Charset(id=113,
                 name='utf16',
                 collation='utf16_lithuanian_ci',
                 is_default=False,
                 maxlen=4),
    114: Charset(id=114,
                 name='utf16',
                 collation='utf16_slovak_ci',
                 is_default=False,
                 maxlen=4),
    115: Charset(id=115,
                 name='utf16',
                 collation='utf16_spanish2_ci',
                 is_default=False,
                 maxlen=4),
    116: Charset(id=116,
                 name='utf16',
                 collation='utf16_roman_ci',
                 is_default=False,
                 maxlen=4),
    117: Charset(id=117,
                 name='utf16',
                 collation='utf16_persian_ci',
                 is_default=False,
                 maxlen=4),
    118: Charset(id=118,
                 name='utf16',
                 collation='utf16_esperanto_ci',
                 is_default=False,
                 maxlen=4),
    119: Charset(id=119,
                 name='utf16',
                 collation='utf16_hungarian_ci',
                 is_default=False,
                 maxlen=4),
    120: Charset(id=120,
                 name='utf16',
                 collation='utf16_sinhala_ci',
                 is_default=False,
                 maxlen=4),
    121: Charset(id=121,
                 name='utf16',
                 collation='utf16_german2_ci',
                 is_default=False,
                 maxlen=4),
    122: Charset(id=122,
                 name='utf16',
                 collation='utf16_croatian_ci',
                 is_default=False,
                 maxlen=4),
    123: Charset(id=123,
                 name='utf16',
                 collation='utf16_unicode_520_ci',
                 is_default=False,
                 maxlen=4),
    124: Charset(id=124,
                 name='utf16',
                 collation='utf16_vietnamese_ci',
                 is_default=False,
                 maxlen=4),
    56: Charset(id=56,
                name='utf16le',
                collation='utf16le_general_ci',
                is_default=True,
                maxlen=4),
    62: Charset(id=62,
                name='utf16le',
                collation='utf16le_bin',
                is_default=False,
                maxlen=4),
    60: Charset(id=60,
                name='utf32',
                collation='utf32_general_ci',
                is_default=True,
                maxlen=4),
    61: Charset(id=61,
                name='utf32',
                collation='utf32_bin',
                is_default=False,
                maxlen=4),
    160: Charset(id=160,
                 name='utf32',
                 collation='utf32_unicode_ci',
                 is_default=False,
                 maxlen=4),
    161: Charset(id=161,
                 name='utf32',
                 collation='utf32_icelandic_ci',
                 is_default=False,
                 maxlen=4),
    162: Charset(id=162,
                 name='utf32',
                 collation='utf32_latvian_ci',
                 is_default=False,
                 maxlen=4),
    163: Charset(id=163,
                 name='utf32',
                 collation='utf32_romanian_ci',
                 is_default=False,
                 maxlen=4),
    164: Charset(id=164,
                 name='utf32',
                 collation='utf32_slovenian_ci',
                 is_default=False,
                 maxlen=4),
    165: Charset(id=165,
                 name='utf32',
                 collation='utf32_polish_ci',
                 is_default=False,
                 maxlen=4),
    166: Charset(id=166,
                 name='utf32',
                 collation='utf32_estonian_ci',
                 is_default=False,
                 maxlen=4),
    167: Charset(id=167,
                 name='utf32',
                 collation='utf32_spanish_ci',
                 is_default=False,
                 maxlen=4),
    168: Charset(id=168,
                 name='utf32',
                 collation='utf32_swedish_ci',
                 is_default=False,
                 maxlen=4),
    169: Charset(id=169,
                 name='utf32',
                 collation='utf32_turkish_ci',
                 is_default=False,
                 maxlen=4),
    170: Charset(id=170,
                 name='utf32',
                 collation='utf32_czech_ci',
                 is_default=False,
                 maxlen=4),
    171: Charset(id=171,
                 name='utf32',
                 collation='utf32_danish_ci',
                 is_default=False,
                 maxlen=4),
    172: Charset(id=172,
                 name='utf32',
                 collation='utf32_lithuanian_ci',
                 is_default=False,
                 maxlen=4),
    173: Charset(id=173,
                 name='utf32',
                 collation='utf32_slovak_ci',
                 is_default=False,
                 maxlen=4),
    174: Charset(id=174,
                 name='utf32',
                 collation='utf32_spanish2_ci',
                 is_default=False,
                 maxlen=4),
    175: Charset(id=175,
                 name='utf32',
                 collation='utf32_roman_ci',
                 is_default=False,
                 maxlen=4),
    176: Charset(id=176,
                 name='utf32',
                 collation='utf32_persian_ci',
                 is_default=False,
                 maxlen=4),
    177: Charset(id=177,
                 name='utf32',
                 collation='utf32_esperanto_ci',
                 is_default=False,
                 maxlen=4),
    178: Charset(id=178,
                 name='utf32',
                 collation='utf32_hungarian_ci',
                 is_default=False,
                 maxlen=4),
    179: Charset(id=179,
                 name='utf32',
                 collation='utf32_sinhala_ci',
                 is_default=False,
                 maxlen=4),
    180: Charset(id=180,
                 name='utf32',
                 collation='utf32_german2_ci',
                 is_default=False,
                 maxlen=4),
    181: Charset(id=181,
                 name='utf32',
                 collation='utf32_croatian_ci',
                 is_default=False,
                 maxlen=4),
    182: Charset(id=182,
                 name='utf32',
                 collation='utf32_unicode_520_ci',
                 is_default=False,
                 maxlen=4),
    183: Charset(id=183,
                 name='utf32',
                 collation='utf32_vietnamese_ci',
                 is_default=False,
                 maxlen=4),
    33: Charset(id=33,
                name='utf8',
                collation='utf8_general_ci',
                is_default=True,
                maxlen=3),
    83: Charset(id=83,
                name='utf8',
                collation='utf8_bin',
                is_default=False,
                maxlen=3),
    192: Charset(id=192,
                 name='utf8',
                 collation='utf8_unicode_ci',
                 is_default=False,
                 maxlen=3),
    193: Charset(id=193,
                 name='utf8',
                 collation='utf8_icelandic_ci',
                 is_default=False,
                 maxlen=3),
    194: Charset(id=194,
                 name='utf8',
                 collation='utf8_latvian_ci',
                 is_default=False,
                 maxlen=3),
    195: Charset(id=195,
                 name='utf8',
                 collation='utf8_romanian_ci',
                 is_default=False,
                 maxlen=3),
    196: Charset(id=196,
                 name='utf8',
                 collation='utf8_slovenian_ci',
                 is_default=False,
                 maxlen=3),
    197: Charset(id=197,
                 name='utf8',
                 collation='utf8_polish_ci',
                 is_default=False,
                 maxlen=3),
    198: Charset(id=198,
                 name='utf8',
                 collation='utf8_estonian_ci',
                 is_default=False,
                 maxlen=3),
    199: Charset(id=199,
                 name='utf8',
                 collation='utf8_spanish_ci',
                 is_default=False,
                 maxlen=3),
    200: Charset(id=200,
                 name='utf8',
                 collation='utf8_swedish_ci',
                 is_default=False,
                 maxlen=3),
    201: Charset(id=201,
                 name='utf8',
                 collation='utf8_turkish_ci',
                 is_default=False,
                 maxlen=3),
    202: Charset(id=202,
                 name='utf8',
                 collation='utf8_czech_ci',
                 is_default=False,
                 maxlen=3),
    203: Charset(id=203,
                 name='utf8',
                 collation='utf8_danish_ci',
                 is_default=False,
                 maxlen=3),
    204: Charset(id=204,
                 name='utf8',
                 collation='utf8_lithuanian_ci',
                 is_default=False,
                 maxlen=3),
    205: Charset(id=205,
                 name='utf8',
                 collation='utf8_slovak_ci',
                 is_default=False,
                 maxlen=3),
    206: Charset(id=206,
                 name='utf8',
                 collation='utf8_spanish2_ci',
                 is_default=False,
                 maxlen=3),
    207: Charset(id=207,
                 name='utf8',
                 collation='utf8_roman_ci',
                 is_default=False,
                 maxlen=3),
    208: Charset(id=208,
                 name='utf8',
                 collation='utf8_persian_ci',
                 is_default=False,
                 maxlen=3),
    209: Charset(id=209,
                 name='utf8',
                 collation='utf8_esperanto_ci',
                 is_default=False,
                 maxlen=3),
    210: Charset(id=210,
                 name='utf8',
                 collation='utf8_hungarian_ci',
                 is_default=False,
                 maxlen=3),
    211: Charset(id=211,
                 name='utf8',
                 collation='utf8_sinhala_ci',
                 is_default=False,
                 maxlen=3),
    212: Charset(id=212,
                 name='utf8',
                 collation='utf8_german2_ci',
                 is_default=False,
                 maxlen=3),
    213: Charset(id=213,
                 name='utf8',
                 collation='utf8_croatian_ci',
                 is_default=False,
                 maxlen=3),
    214: Charset(id=214,
                 name='utf8',
                 collation='utf8_unicode_520_ci',
                 is_default=False,
                 maxlen=3),
    215: Charset(id=215,
                 name='utf8',
                 collation='utf8_vietnamese_ci',
                 is_default=False,
                 maxlen=3),
    223: Charset(id=223,
                 name='utf8',
                 collation='utf8_general_mysql500_ci',
                 is_default=False,
                 maxlen=3),
    45: Charset(id=45,
                name='utf8mb4',
                collation='utf8mb4_general_ci',
                is_default=True,
                maxlen=4),
    46: Charset(id=46,
                name='utf8mb4',
                collation='utf8mb4_bin',
                is_default=False,
                maxlen=4),
    224: Charset(id=224,
                 name='utf8mb4',
                 collation='utf8mb4_unicode_ci',
                 is_default=False,
                 maxlen=4),
    225: Charset(id=225,
                 name='utf8mb4',
                 collation='utf8mb4_icelandic_ci',
                 is_default=False,
                 maxlen=4),
    226: Charset(id=226,
                 name='utf8mb4',
                 collation='utf8mb4_latvian_ci',
                 is_default=False,
                 maxlen=4),
    227: Charset(id=227,
                 name='utf8mb4',
                 collation='utf8mb4_romanian_ci',
                 is_default=False,
                 maxlen=4),
    228: Charset(id=228,
                 name='utf8mb4',
                 collation='utf8mb4_slovenian_ci',
                 is_default=False,
                 maxlen=4),
    229: Charset(id=229,
                 name='utf8mb4',
                 collation='utf8mb4_polish_ci',
                 is_default=False,
                 maxlen=4),
    230: Charset(id=230,
                 name='utf8mb4',
                 collation='utf8mb4_estonian_ci',
                 is_default=False,
                 maxlen=4),
    231: Charset(id=231,
                 name='utf8mb4',
                 collation='utf8mb4_spanish_ci',
                 is_default=False,
                 maxlen=4),
    232: Charset(id=232,
                 name='utf8mb4',
                 collation='utf8mb4_swedish_ci',
                 is_default=False,
                 maxlen=4),
    233: Charset(id=233,
                 name='utf8mb4',
                 collation='utf8mb4_turkish_ci',
                 is_default=False,
                 maxlen=4),
    234: Charset(id=234,
                 name='utf8mb4',
                 collation='utf8mb4_czech_ci',
                 is_default=False,
                 maxlen=4),
    235: Charset(id=235,
                 name='utf8mb4',
                 collation='utf8mb4_danish_ci',
                 is_default=False,
                 maxlen=4),
    236: Charset(id=236,
                 name='utf8mb4',
                 collation='utf8mb4_lithuanian_ci',
                 is_default=False,
                 maxlen=4),
    237: Charset(id=237,
                 name='utf8mb4',
                 collation='utf8mb4_slovak_ci',
                 is_default=False,
                 maxlen=4),
    238: Charset(id=238,
                 name='utf8mb4',
                 collation='utf8mb4_spanish2_ci',
                 is_default=False,
                 maxlen=4),
    239: Charset(id=239,
                 name='utf8mb4',
                 collation='utf8mb4_roman_ci',
                 is_default=False,
                 maxlen=4),
    240: Charset(id=240,
                 name='utf8mb4',
                 collation='utf8mb4_persian_ci',
                 is_default=False,
                 maxlen=4),
    241: Charset(id=241,
                 name='utf8mb4',
                 collation='utf8mb4_esperanto_ci',
                 is_default=False,
                 maxlen=4),
    242: Charset(id=242,
                 name='utf8mb4',
                 collation='utf8mb4_hungarian_ci',
                 is_default=False,
                 maxlen=4),
    243: Charset(id=243,
                 name='utf8mb4',
                 collation='utf8mb4_sinhala_ci',
                 is_default=False,
                 maxlen=4),
    244: Charset(id=244,
                 name='utf8mb4',
                 collation='utf8mb4_german2_ci',
                 is_default=False,
                 maxlen=4),
    245: Charset(id=245,
                 name='utf8mb4',
                 collation='utf8mb4_croatian_ci',
                 is_default=False,
                 maxlen=4),
    246: Charset(id=246,
                 name='utf8mb4',
                 collation='utf8mb4_unicode_520_ci',
                 is_default=False,
                 maxlen=4),
    247: Charset(id=247,
                 name='utf8mb4',
                 collation='utf8mb4_vietnamese_ci',
                 is_default=False,
                 maxlen=4),
}


def lookup(charset_id):
    """Lookup a character set by id

    :returns: ``Charset`` instance if found
    :raises: LookupError if no matching charset was found
    """
    try:
        return CHARSETS[charset_id]
    except KeyError:
        raise LookupError("Charset id '%d' not found" % charset_id)
